@@ -103,7 +103,7 @@ def plotting(cfg: PlotmanConfig):
                 minp.ParallelWorker(cfg.scheduling, cfg.directories)
 
             if cfg.apis.target is not "":
-                PostDat(Job.get_jobs_json(minp.LsJobs), cfg)
+                PostDat(minp.GenStatus(minp.LsJobs), cfg)
 
             print(f"s{cfg.scheduling.polling_time_s}\n")
             time.sleep(cfg.scheduling.polling_time_s)
@@ -223,15 +223,15 @@ def main():
         elif args.cmd == 'api':
             apiOpen(cfg)
 
+        elif args.cmd == 'nfs':
+            farm = FarmPlot(cfg)
+            farm.start_copyplot_spawn()
+
         # Start running archival
         elif args.cmd == 'archive':
             with concurrent.futures.ThreadPoolExecutor(max_workers=10) as executor:
                 executor.submit(archivePlots, cfg)
 
-        elif args.cmd == 'nfs':
-            farm = FarmPlot(cfg)
-            farm.start_copyplot_spawn()
-
         # Debugging: show the destination drive usage schedule
         elif args.cmd == 'dsched':
             for (d, ph) in manager.dstdirs_to_furthest_phase(jobs).items():
