@@ -4,7 +4,7 @@ import os
 import psutil
 import texttable as tt  # from somewhere?
 
-from . import archive, job, manager, plot_util
+from . import archive, job, manager, plot_util, configuration
 
 
 def abbr_path(path, putative_prefix):
@@ -135,7 +135,7 @@ def status_report(jobs, width, height=None, tmp_prefix='', dst_prefix=''):
                            ]
             except (psutil.NoSuchProcess, psutil.AccessDenied):
                 # In case the job has disappeared
-                row = [j.plot_id[:8]] + (['--'] * headingwidth)
+                row = [j.plot_id[:8]] + (['--'] * (headingwidth - 1))
 
             if height:
                 row.insert(0, '%3d' % i)
@@ -186,9 +186,12 @@ def dst_dir_report(jobs, dstdirs, width, prefix=''):
         dir_plots = plot_util.list_k32_plots(d)
         gb_free = int(plot_util.df_b(d) / plot_util.GB)
         n_plots = len(dir_plots)
+
         priority = archive.compute_priority(eldest_ph, gb_free, n_plots)
+
         row = [abbr_path(d, prefix), n_plots, gb_free,
                phases_str(phases, 5), priority]
+
         tab.add_row(row)
     tab.set_max_width(width)
     tab.set_deco(tt.Texttable.BORDER | tt.Texttable.HEADER)
@@ -214,15 +217,50 @@ def arch_dir_report(archdir_freebytes, width, prefix=''):
 
 # TODO: remove this
 def dirs_report(jobs, dir_cfg, sched_cfg, width):
+    (is_dst, dst_dir) = configuration.get_dst_directories(dir_cfg)
+    """
     reports = [
         tmp_dir_report(jobs, dir_cfg, sched_cfg, width),
         dst_dir_report(jobs, dir_cfg.dst, width),
     ]
+    
     if dir_cfg.archive is not None:
         reports.extend([
             'archive dirs free space:',
             arch_dir_report(archive.get_archdir_freebytes(dir_cfg.archive), width),
         ])
+    """
+    # return '\n'.join(reports) + '\n'
+    return (
+        tmp_dir_report(jobs, dir_cfg, sched_cfg, width) + '\n' +
+        dst_dir_report(jobs, dst_dir, width) + '\n' +
+        'archive dirs free space:\n' +
+        arch_dir_report(archive.get_archdir_freebytes(dir_cfg.archive), width) + '\n'
+    )
 
-    return '\n'.join(reports) + '\n'
 
+
+def jsondata(jobs, tmp_prefix='', dst_prefix='') -> list:
+    jobsr = list()
+    for i, j in enumerate(sorted(jobs, key=job.Job.get_time_wall)):
+        with j.proc.oneshot():
+            dictionary = {
+                'plotid': j.plot_id[:8],
+                'k': j.k,
+                'tmp': abbr_path(j.tmpdir, tmp_prefix),
+                'dst': abbr_path(j.dstdir, dst_prefix),
+                'wall': plot_util.time_format(j.get_time_wall()),
+                'phase': phase_str(j.progress()),
+                'tmpdisk': plot_util.human_format(j.get_tmp_usage(), 0),
+                'pid': j.proc.pid,
+                'stat': j.get_run_status(),
+                'mem': plot_util.human_format(j.get_mem_usage(), 1),
+                'user': plot_util.time_format(j.get_time_user()),
+                'sys': plot_util.time_format(j.get_time_sys()),
+                'io': plot_util.time_format(j.get_time_iowait()),
+                'freezed': plot_util.is_freezed(j),
+                'logfile': os.path.basename(j.logfile)
+            }
+            jobsr.append(dictionary)
+
+    return jobsr
